Better cpdef override check (use method in C API rather than strcmp).
[cython.git] / cython.py
index f32cf1538c0d84d8be7a19314129eb5a9d0fd5c3..c84a8003c83f7184dc761f1a30f3e871a4b58f42 100644 (file)
--- a/cython.py
+++ b/cython.py
@@ -1,6 +1,12 @@
 #
#   Pyrex -- Main Program, generic
 #
 
-from Pyrex.Compiler.Main import main
-main(command_line = 1)
+if __name__ == '__main__':
+
+    from Cython.Compiler.Main import main
+    main(command_line = 1)
+
+else:
+    # Void cython.* directives. 
+    from Cython.Shadow import *
@@ -1,6 +1,12 @@
 #
-#   Pyrex -- Main Program, generic
+#   Cython -- Main Program, generic
 #
 